==> codeforlife_portal-2.9.1-py2.py3-none-any.whl: portal/tests/pageObjects/portal/password_reset_form_page.py <==
# -*- coding: utf-8 -*-
# Code for Life
#
# Copyright (C) 2018, Ocado Innovation Limited
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# ADDITIONAL TERMS – Section 7 GNU General Public Licence
#
# This licence does not grant any right, title or interest in any “Ocado” logos,
# trade names or the trademark “Ocado” or any other trademarks or domain names
# owned by Ocado Innovation Limited or the Ocado group of companies or any other
# distinctive brand features of “Ocado” as may be secured from time to time. You
# must not distribute any modification of this program using the trademark
# “Ocado” or claim any affiliation or association with Ocado or its employees.
#
# You are not authorised to use the name Ocado (or any of its trade names) or
# the names of any author or contributor in advertising or for publicity purposes
# pertaining to the distribution of this program, without the prior written
# authorisation of Ocado.
#
# Any propagation, distribution or conveyance of this program must include this
# copyright notice and these terms. You must not misrepresent the origins of this
# program; modified versions of the program must be marked as such and not
# identified as the original program.
from base_page import BasePage


class PasswordResetPage(BasePage):
    def __init__(self, browser):
        super(PasswordResetPage, self).__init__(browser)

        assert self.on_correct_page("reset_password_form_page")

    def teacher_reset_password(self, new_password):
        self.clear_and_fill("new_password1", new_password)
        self.clear_and_fill("new_password2", new_password)

        self.browser.find_element_by_id("teacher_update_button").click()

        self.wait_for_element_by_id("reset_password_done_page")

        return self

    def student_reset_password(self, new_password):
        self.clear_and_fill("new_password1", new_password)
        self.clear_and_fill("new_password2", new_password)

        self.browser.find_element_by_id("student_update_button").click()

        self.wait_for_element_by_id("reset_password_done_page")

        return self

    def clear_and_fill(self, field, value):
        self.browser.find_element_by_id("id_" + field).clear()
        self.browser.find_element_by_id("id_" + field).send_keys(value)

==> codeforlife_portal-4.20.1-py2.py3-none-any.whl: portal/tests/pageObjects/portal/password_reset_form_page.py <==
# -*- coding: utf-8 -*-
# Code for Life
#
# Copyright (C) 2018, Ocado Innovation Limited
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# ADDITIONAL TERMS – Section 7 GNU General Public Licence
#
# This licence does not grant any right, title or interest in any “Ocado” logos,
# trade names or the trademark “Ocado” or any other trademarks or domain names
# owned by Ocado Innovation Limited or the Ocado group of companies or any other
# distinctive brand features of “Ocado” as may be secured from time to time. You
# must not distribute any modification of this program using the trademark
# “Ocado” or claim any affiliation or association with Ocado or its employees.
#
# You are not authorised to use the name Ocado (or any of its trade names) or
# the names of any author or contributor in advertising or for publicity purposes
# pertaining to the distribution of this program, without the prior written
# authorisation of Ocado.
#
# Any propagation, distribution or conveyance of this program must include this
# copyright notice and these terms. You must not misrepresent the origins of this
# program; modified versions of the program must be marked as such and not
# identified as the original program.
from __future__ import absolute_import

from .base_page import BasePage


class PasswordResetPage(BasePage):
    def __init__(self, browser):
        super(PasswordResetPage, self).__init__(browser)

        assert self.on_correct_page("reset_password_form_page")

    def teacher_reset_password(self, new_password):
        self.clear_and_fill("new_password1", new_password)
        self.clear_and_fill("new_password2", new_password)

        self.browser.find_element_by_id("teacher_update_button").click()

        self.wait_for_element_by_id("reset_password_done_page")

        return self

    def student_reset_password(self, new_password):
        self.clear_and_fill("new_password1", new_password)
        self.clear_and_fill("new_password2", new_password)

        self.browser.find_element_by_id("student_update_button").click()

        self.wait_for_element_by_id("reset_password_done_page")

        return self

    def clear_and_fill(self, field, value):
        self.browser.find_element_by_id("id_" + field).clear()
        self.browser.find_element_by_id("id_" + field).send_keys(value)
